_G.NPCFlashlights = _G.NPCFlashlights or {
	mod_path = ModPath,
	save_path = SavePath .. 'More_NPC_Flashlights.txt',
	loc_path = ModPath .. 'loc/english.json',
	settings = {}
}

function NPCFlashlights:load()
	local file = io.open(self.save_path, 'r')
	if file then
		for k, v in pairs(json.decode(file:read('*all'))) do
			self.settings[k] = v
		end
		file:close()
	end
end

function NPCFlashlights:save()
	local file = io.open(self.save_path, 'w+')
	if file then
		file:write(json.encode(self.settings))
		file:close()
	end
end

Hooks:Add("LocalizationManagerPostInit", "flashlight_LocalizationManagerPostInit", function( loc )
	loc:load_localization_file(NPCFlashlights.loc_path)
end)

Hooks:Add("MenuManagerInitialize", "flashlight_MenuManagerInitialize", function(menu_manager)
	MenuCallbackHandler.NPCFlashlights_check_clbk = function(self, item)
		local name = item:name()
		local state = item:value()
	
		NPCFlashlights.settings[name] = state

		local level_id = Global.level_data and Global.level_data.level_id
		if level_id == name and managers.game_play_central then
			managers.game_play_central:set_flashlights_on()
		end
	end

	MenuCallbackHandler.NPCFlashlights_callback_options_closed = function(self)
		NPCFlashlights:save()
	end

	Hooks:Add("MenuManagerBuildCustomMenus", "NPCFlashlights_MenuManagerBuildCustomMenus", function(menu_manager, nodes)
		NPCFlashlights:load()

		local menu_id = "NPCFlashlights"
		MenuHelper:NewMenu(menu_id)

		local level_tweak = tweak_data.levels
		for _, level_id in ipairs(level_tweak:get_level_index()) do
			local level = level_tweak[level_id]
			if level then
				if NPCFlashlights.settings[level_id] == nil then
					NPCFlashlights.settings[level_id] = 2
				end

				local state = NPCFlashlights.settings[level_id]

				MenuHelper:AddMultipleChoice({
					id = level_id,
					title = level.name_id,
					callback = "NPCFlashlights_check_clbk",
					items = {
						"NPCFlashlights_force_disable",
						"NPCFlashlights_let_map_decide",
						"NPCFlashlights_force_enable"
					},
					value = state,
					localized_items = true,
					localize = true,
					menu_id = menu_id
				})
			end
		end

		NPCFlashlights:save()

		nodes[menu_id] = MenuHelper:BuildMenu(menu_id, {back_callback = "NPCFlashlights_callback_options_closed"})
		MenuHelper:AddMenuItem(nodes["blt_options"] or nodes["lua_mod_options_menu"], menu_id, "NPCFlashlights_options", "NPCFlashlights_options_desc") -- lua_mod_options_menu is compatibility for pre-BLT 2.0
	end)
end)